"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskManager = exports.TaskManagerFactory = void 0;
const internal_1 = require("@fluidframework/shared-object-base/internal");
const packageVersion_js_1 = require("./packageVersion.js");
const taskManager_js_1 = require("./taskManager.js");
/**
 * The factory that defines the task queue
 */
class TaskManagerFactory {
    get type() {
        return TaskManagerFactory.Type;
    }
    get attributes() {
        return TaskManagerFactory.Attributes;
    }
    /**
     * {@inheritDoc @fluidframework/datastore-definitions#IChannelFactory.load}
     */
    async load(runtime, id, services, attributes) {
        const taskQueue = new taskManager_js_1.TaskManagerClass(id, runtime, attributes);
        await taskQueue.load(services);
        return taskQueue;
    }
    create(document, id) {
        const taskQueue = new taskManager_js_1.TaskManagerClass(id, document, this.attributes);
        taskQueue.initializeLocal();
        return taskQueue;
    }
}
exports.TaskManagerFactory = TaskManagerFactory;
TaskManagerFactory.Type = "https://graph.microsoft.com/types/task-manager";
TaskManagerFactory.Attributes = {
    type: TaskManagerFactory.Type,
    snapshotFormatVersion: "0.1",
    packageVersion: packageVersion_js_1.pkgVersion,
};
/**
 * {@inheritDoc ITaskManager}
 * @legacy
 * @alpha
 */
exports.TaskManager = (0, internal_1.createSharedObjectKind)(TaskManagerFactory);
//# sourceMappingURL=taskManagerFactory.js.map