/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { createSharedObjectKind } from "@fluidframework/shared-object-base/internal";
import { pkgVersion } from "./packageVersion.js";
import { TaskManagerClass } from "./taskManager.js";
/**
 * The factory that defines the task queue
 */
export class TaskManagerFactory {
    get type() {
        return TaskManagerFactory.Type;
    }
    get attributes() {
        return TaskManagerFactory.Attributes;
    }
    /**
     * {@inheritDoc @fluidframework/datastore-definitions#IChannelFactory.load}
     */
    async load(runtime, id, services, attributes) {
        const taskQueue = new TaskManagerClass(id, runtime, attributes);
        await taskQueue.load(services);
        return taskQueue;
    }
    create(document, id) {
        const taskQueue = new TaskManagerClass(id, document, this.attributes);
        taskQueue.initializeLocal();
        return taskQueue;
    }
}
TaskManagerFactory.Type = "https://graph.microsoft.com/types/task-manager";
TaskManagerFactory.Attributes = {
    type: TaskManagerFactory.Type,
    snapshotFormatVersion: "0.1",
    packageVersion: pkgVersion,
};
/**
 * {@inheritDoc ITaskManager}
 * @legacy
 * @alpha
 */
export const TaskManager = createSharedObjectKind(TaskManagerFactory);
//# sourceMappingURL=taskManagerFactory.js.map